@@ -1,12 +1,15 @@
 #!/usr/bin/python
-# Importing required modules
-import test_2
+# Importing data linker package
 import datalinker
+
+# Create a object using datalinker library
 data = datalinker.DataLinker().run()
 
+import test_2
+
 if __name__ == '__main__':
 	# Setting the data
-	data.set("message", "Hello World!!")
+	data.push("message", "Hello World!!")
 
 	# Calling test_2.py
 	test_2.print_msg()
\ No newline at end of file
